import random
print("Hello from Saksham Jain")
class Joke:
    def getJoke(lan):
          jokelist=["Is it true that cannibals don't eat clowns because they taste funny",

                    "What kind of pig can you ignore at a party? A wild bore.",

                    "Why do Marxists like fruit infusions? Because all proper tea is theft!",

                    "What was born to succeed? A budgie with a blunt beak.",

                    "What lies on the bottom of the ocean and shakes? A nervous wreck.",

                    "What's brown and sticky? A stick",

                    "Q. Where do you keep a baby ape? A In an apricot",

                    "Close your eyes. Dark isn't it?",

                    "What do you call an aarvark that has been beaten up? A vark.",

                    "- Can you swim?- Some times.- What do you mean by some times? - Only when I'm in the water.",

                    "Why do bees hum ? Because they don't know the words",

                    "What's orange and sounds like a parrot? A carrot!",

                    "Why do elephants have big ears?Noddy wouldn't pay the ransom"
                   ]
          print(random.choice(jokelist))



from setuptools import setup
setup(name="jokegenerate",
version="0.1",
description="This is module is made by Saksham Jain",
long_description = "This is a very very long description",
author="Saksham Jain",
packages=['jokegenerate'],
install_requires=[])
